@@ -1,4 +1,6 @@
 """
+Generate test code tool
+
 copyrigth https://github.com/shigeshige/py-ut-generator
 定数一覧
 """
@@ -18,3 +20,13 @@ AST_ASSIGN = 'Assign'
 AST_WHILE = 'While'
 AST_WITH = 'With'
 AST_CLASS = 'ClassDef'
+AST_COMP = 'Compare'
+AST_CONST = 'Constant'
+AST_NAME = 'Name'
+AST_OPE = 'UnaryOp'
+
+STR_PRE_FUNC = 'test_'
+
+FUNC_OPEN = 'open'
+
+BUILDINS = [FUNC_OPEN]
